### A simple timeline

### A simple timeline without Axis

### It works with circles too

### Combine circles and rectangles

### A stacked timeline with hover, click, and scroll events

### We can also use icons

### We can change colors and put labels

### We can also rotate tick mark labels

### A timeline with colors mapped from the data

### A timeline with colors mapped from the data for individual time objects

### A timeline with relative timepoints

### A stacked timeline with axis on top

### A stacked timeline with backgrounds

### A stacked timeline with backgrounds and ticks

### A complex timeline